package problem.fdr;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class FDRProblem {
	
	private final FDRVar[] variables;
	private final FDRPartialState init;
	private final FDRPartialState goal;
	private final List<FDROperator> operators = new ArrayList<>();
	
	public FDRProblem(FDRVar[] variables, FDRPartialState init, FDRPartialState goal, Collection<FDROperator> operators) {
		super();
		this.variables = variables;
		this.init = init;
		this.goal = goal;
		this.operators.addAll(operators);
	}

	public FDRVar[] getVariables() {
		return variables;
	}

	public FDRPartialState getInit() {
		return init;
	}

	public FDRPartialState getGoal() {
		return goal;
	}

	public List<FDROperator> getOperators() {
		return operators;
	}
	
	public String humanize(FDRPartialState state) {
		String out = "{";
		for(int var : state.getSetVariables()) {
			out += "var"+var+"="+variables[var].getName(state.getValue(var)) + ",";
		}
		out += "}";
		return out;
	}

	@Override
	public String toString() {
		String out = "FDRProblem:\nvariables:\n";
		for(FDRVar var : variables) {
			out += " var " + var.getVarID() + "\n";
			for(int val=0 ; val < var.getRange() ; val++) {
				out += "  " + var.getName(val) + "\n";
			}
		}
		out += "init:\n"+humanize(init)+"\n";
		out += "goal:\n"+humanize(goal)+"\n";
		out += "operators:\n";
		for(FDROperator op : operators){
			out += " "+op.getName()+"\n";
			out += "  pre:"+humanize(op.getPre())+"\n";
			out += "  eff:"+humanize(op.getEff())+"\n";
			out += "  cost:"+op.getCost()+"\n";
		}
		
		
		return out;
	}
	
	
	
	
}
